@@ -8,7 +8,7 @@ use URI::Escape;
 use Encode;
 
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 
 my %lang_pairs = (
@@ -138,6 +138,7 @@ sub translate {
     }
     
     my $translated = _fix_translated($response->{'_content'});
+    
     $translated = decode_utf8($translated);
     
     if ($self->{output} eq 'marked_text') {
@@ -249,7 +250,7 @@ WWW::Translate::Apertium - Open source machine translation
 
 =head1 VERSION
 
-Version 0.07 December 12, 2008
+Version 0.08 December 13, 2008
 
 
 =head1 SYNOPSIS
@@ -296,7 +297,7 @@ University of Alicante, the University of Vigo and the Pompeu Fabra University.
 For more details, see L<http://apertium.sourceforge.net/>.
 
 WWW::Translate::Apertium provides an object oriented interface to the Apertium
-online machine translation test drive, based on Apertium 3.0.
+online machine translation web service, based on Apertium 3.0.
 
 Currently, Apertium supports the following language pairs:
 
@@ -489,20 +490,19 @@ Apertium engine object:
 =head2 $engine->translate($string)
 
 Returns the translation of $string generated by Apertium, encoded as UTF-8.
+In case the server is down, the C<translate> method will show a warning and
+return C<undef>.
 
 The input $string must be an UTF-8 encoded string (for this task you can use
 the Encode module or the PerlIO layer, if you are reading the text from a file).
 
-If you are going to translate a literal string included in the code and then
+If you are going to translate a string literal included in the code and then
 display the result in the output window of the code editor, then you should add
 the following statement to your code in order to avoid a "Wide character in
 print" warning:
 
     binmode(STDOUT, ':utf8');
 
-In case the server is down, the C<translate> method will show a warning and
-return C<undef>.
-
 
 =head2 $engine->from_into($lang_pair)
 
@@ -571,7 +571,13 @@ WWW::Translate::interNOSTRUM
 
 Apertium project website:
 
-L<http://apertium.sourceforge.net/>
+L<http://www.apertium.org/>
+
+If you want to get I<the real thing> and install the Apertium software on your
+local machine, you can download the Apertium code and build it on your system.
+You will find detailed setup instructions in the Apertium wiki:
+
+L<http://wiki.apertium.org/wiki/Installation>
 
 =head1 ACKNOWLEDGEMENTS
 
